@@ -31,7 +31,7 @@ travis_script() {
     -e ENABLE_ARCH_x86_64=$x86_64 \
     -e ENABLE_TEST=true \
     -e EXTRA_CMAKE_FLAGS="-DBOOTSTRAP_DAEMON=OFF -DMIN_LOGGER_LEVEL=DEBUG -DTEST_TIMEOUT_SECONDS=90 -DAUTOTEST=ON" \
-    -e DCMAKE_C_FLAGS="$C_FLAGS" \
+    -e CMAKE_C_FLAGS="$C_FLAGS" \
     -e CMAKE_CXX_FLAGS="$CXX_FLAGS" \
     -e CMAKE_EXE_LINKER_FLAGS="$LD_FLAGS" \
     -e CMAKE_SHARED_LINKER_FLAGS="$LD_FLAGS" \
