@@ -1,23 +1,7 @@
-/*
+/* SPDX-License-Identifier: GPL-3.0-or-later
  * Copyright © 2016-2018 The TokTok team.
  * Copyright © 2013 Tox project.
  * Copyright © 2013 plutooo
- *
- * This file is part of Tox, the free peer to peer instant messenger.
- * This file is donated to the Tox Project.
- *
- * Tox is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * Tox is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Tox.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "ring_buffer.h"
 
@@ -85,8 +69,9 @@ RingBuffer *rb_new(int size)
     }
 
     buf->size = size + 1; /* include empty elem */
+    buf->data = (void **)calloc(buf->size, sizeof(void *));
 
-    if (!(buf->data = (void **)calloc(buf->size, sizeof(void *)))) {
+    if (!buf->data) {
         free(buf);
         return nullptr;
     }
@@ -118,7 +103,7 @@ uint16_t rb_data(const RingBuffer *b, void **dest)
 {
     uint16_t i = 0;
 
-    for (; i < rb_size(b); i++) {
+    for (; i < rb_size(b); ++i) {
         dest[i] = b->data[(b->start + i) % b->size];
     }
 
