@@ -1,25 +1,10 @@
-/*
- * LAN discovery implementation.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * Copyright © 2016-2018 The TokTok team.
+ * Copyright © 2013 Tox project.
  */
 
 /*
- * Copyright © 2016-2018 The TokTok team.
- * Copyright © 2013 Tox project.
- *
- * This file is part of Tox, the free peer to peer instant messenger.
- *
- * Tox is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * Tox is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Tox.  If not, see <http://www.gnu.org/licenses/>.
+ * LAN discovery implementation.
  */
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -72,8 +57,8 @@ static void fetch_broadcast_info(uint16_t port)
         }
     }
 
-    /* We copy these to the static variables broadcast_* only at the end of fetch_broadcast_info().
-     * The intention is to ensure that even if multiple threads enter fetch_broadcast_info() concurrently, only valid
+    /* We copy these to the static variables `broadcast_*` only at the end of `fetch_broadcast_info()`.
+     * The intention is to ensure that even if multiple threads enter `fetch_broadcast_info()` concurrently, only valid
      * interfaces will be set to be broadcast to.
      * */
     int count = 0;
@@ -138,7 +123,7 @@ static void fetch_broadcast_info(uint16_t port)
 static void fetch_broadcast_info(uint16_t port)
 {
     /* Not sure how many platforms this will run on,
-     * so it's wrapped in __linux for now.
+     * so it's wrapped in `__linux__` for now.
      * Definitely won't work like this on Windows...
      */
     broadcast_count = 0;
@@ -161,15 +146,15 @@ static void fetch_broadcast_info(uint16_t port)
         return;
     }
 
-    /* We copy these to the static variables broadcast_* only at the end of fetch_broadcast_info().
-     * The intention is to ensure that even if multiple threads enter fetch_broadcast_info() concurrently, only valid
+    /* We copy these to the static variables `broadcast_*` only at the end of `fetch_broadcast_info()`.
+     * The intention is to ensure that even if multiple threads enter `fetch_broadcast_info()` concurrently, only valid
      * interfaces will be set to be broadcast to.
      * */
     int count = 0;
     IP_Port ip_ports[MAX_INTERFACES];
 
-    /* ifc.ifc_len is set by the ioctl() to the actual length used;
-     * on usage of the complete array the call should be repeated with
+    /* `ifc.ifc_len` is set by the `ioctl()` to the actual length used.
+     * On usage of the complete array the call should be repeated with
      * a larger array, not done (640kB and 16 interfaces shall be
      * enough, for everybody!)
      */
@@ -186,7 +171,7 @@ static void fetch_broadcast_info(uint16_t port)
             continue;
         }
 
-        struct sockaddr_in *sock4 = (struct sockaddr_in *)&i_faces[i].ifr_broadaddr;
+        struct sockaddr_in *sock4 = (struct sockaddr_in *)(void *)&i_faces[i].ifr_broadaddr;
 
         if (count >= MAX_INTERFACES) {
             break;
@@ -254,8 +239,8 @@ static IP broadcast_ip(Family family_socket, Family family_broadcast)
     if (net_family_is_ipv6(family_socket)) {
         if (net_family_is_ipv6(family_broadcast)) {
             ip.family = net_family_ipv6;
-            /* FF02::1 is - according to RFC 4291 - multicast all-nodes link-local */
-            /* FE80::*: MUST be exact, for that we would need to look over all
+            /* `FF02::1` is - according to RFC 4291 - multicast all-nodes link-local */
+            /* `FE80::*:` MUST be exact, for that we would need to look over all
              * interfaces and check in which status they are */
             ip.ip.v6.uint8[ 0] = 0xFF;
             ip.ip.v6.uint8[ 1] = 0x02;
@@ -343,8 +328,8 @@ bool ip_is_lan(IP ip)
     }
 
     if (net_family_is_ipv6(ip.family)) {
-        /* autogenerated for each interface: FE80::* (up to FEBF::*)
-           FF02::1 is - according to RFC 4291 - multicast all-nodes link-local */
+        /* autogenerated for each interface: `FE80::*` (up to `FEBF::*`)
+           `FF02::1` is - according to RFC 4291 - multicast all-nodes link-local */
         if (((ip.ip.v6.uint8[0] == 0xFF) && (ip.ip.v6.uint8[1] < 3) && (ip.ip.v6.uint8[15] == 1)) ||
                 ((ip.ip.v6.uint8[0] == 0xFE) && ((ip.ip.v6.uint8[1] & 0xC0) == 0x80))) {
             return true;
