@@ -1,26 +1,11 @@
 %{
-/*
- * The Tox public API.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * Copyright © 2016-2018 The TokTok team.
+ * Copyright © 2013 Tox project.
  */
 
 /*
- * Copyright © 2016-2018 The TokTok team.
- * Copyright © 2013 Tox project.
- *
- * This file is part of Tox, the free peer to peer instant messenger.
- *
- * Tox is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * Tox is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Tox.  If not, see <http://www.gnu.org/licenses/>.
+ * The Tox public API.
  */
 #ifndef C_TOXCORE_TOXCORE_TOX_H
 #define C_TOXCORE_TOXCORE_TOX_H
@@ -29,6 +14,8 @@
 #include <stddef.h>
 #include <stdint.h>
 
+//!TOKSTYLE-
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -182,7 +169,7 @@ const VERSION_MINOR                = 2;
  * The patch or revision number. Incremented when bugfixes are applied without
  * changing any functionality or API or ABI.
  */
-const VERSION_PATCH                = 10;
+const VERSION_PATCH                = 12;
 
 /**
  * A macro to check at preprocessing time whether the client code is compatible
@@ -623,6 +610,21 @@ static class options {
        */
       any user_data;
     }
+
+    /**
+     * These options are experimental, so avoid writing code that depends on
+     * them. Options marked "experimental" may change their behaviour or go away
+     * entirely in the future, or may be renamed to something non-experimental
+     * if they become part of the supported API.
+     */
+    namespace experimental {
+      /**
+       * Make public API functions thread-safe using a per-instance lock.
+       *
+       * Default: false.
+       */
+      bool thread_safety;
+    }
   }
 
 
@@ -854,7 +856,7 @@ enum class CONNECTION {
 }
 
 
-inline namespace self {
+namespace self {
 
   CONNECTION connection_status {
     /**
@@ -908,7 +910,7 @@ void iterate(any user_data);
  ******************************************************************************/
 
 
-inline namespace self {
+namespace self {
 
   uint8_t[ADDRESS_SIZE] address {
     /**
@@ -986,7 +988,7 @@ error for set_info {
 }
 
 
-inline namespace self {
+namespace self {
 
   uint8_t[length <= MAX_NAME_LENGTH] name {
     /**
@@ -1226,7 +1228,7 @@ namespace friend {
 
 }
 
-inline namespace self {
+namespace self {
 
   uint32_t[size] friend_list {
     /**
@@ -1514,8 +1516,14 @@ namespace friend {
  *
  ******************************************************************************/
 
+error for set_typing {
+  /**
+   * The friend number did not designate a valid friend.
+   */
+  FRIEND_NOT_FOUND,
+}
 
-inline namespace self {
+namespace self {
 
   bool typing {
     /**
@@ -1528,12 +1536,7 @@ inline namespace self {
      *
      * @return true on success.
      */
-    set(uint32_t friend_number) {
-      /**
-       * The friend number did not designate a valid friend.
-       */
-      FRIEND_NOT_FOUND,
-    }
+    set(uint32_t friend_number) with error for set_typing;
   }
 
 }
@@ -2232,7 +2235,7 @@ namespace conference {
   /**
    * Creates a new conference.
    *
-   * This function creates a new text conference.
+   * This function creates and connects to a new text conference.
    *
    * @return conference number on success, or an unspecified value on failure.
    */
@@ -2279,7 +2282,10 @@ namespace conference {
   namespace peer {
 
     /**
-     * Return the number of peers in the conference. Return value is unspecified on failure.
+     * Return the number of online peers in the conference. The unsigned
+     * integers less than this number are the valid values of peer_number for
+     * the functions querying these peers. Return value is unspecified on
+     * failure.
      */
     const uint32_t count(uint32_t conference_number)
         with error for peer_query;
@@ -2327,7 +2333,9 @@ namespace conference {
   namespace offline_peer {
 
     /**
-     * Return the number of offline peers in the conference. Return value is unspecified on failure.
+     * Return the number of offline peers in the conference. The unsigned
+     * integers less than this number are the valid values of offline_peer_number for
+     * the functions querying these peers. Return value is unspecified on failure.
      */
     const uint32_t count(uint32_t conference_number)
         with error for peer_query;
@@ -2388,10 +2396,6 @@ namespace conference {
   /**
    * Invites a friend to a conference.
    *
-   * We must be connected to the conference, meaning that the conference has not
-   * been deleted, and either we created the conference with the $new function,
-   * or a `${event connected}` event has occurred for the conference.
-   *
    * @param friend_number The friend number of the friend we want to invite.
    * @param conference_number The conference number of the conference we want to invite the friend to.
    *
@@ -2416,6 +2420,14 @@ namespace conference {
   /**
    * Joins a conference that the client has been invited to.
    *
+   * After successfully joining the conference, the client will not be "connected"
+   * to it until a handshaking procedure has been completed. A
+   * `${event connected}` event will then occur for the conference. The client
+   * will then remain connected to the conference until the conference is deleted,
+   * even across core restarts. Many operations on a conference will fail with a
+   * corresponding error if attempted on a conference to which the client is not
+   * yet connected.
+   *
    * @param friend_number The friend number of the friend who sent the invite.
    * @param cookie Received via the `${event invite}` event.
    * @param length The size of cookie.
@@ -2552,8 +2564,16 @@ namespace conference {
     size();
 
     /**
-     * Copy a list of valid conference IDs into the array chatlist. Determine how much space
-     * to allocate for the array with the `$size` function.
+     * Copy a list of valid conference numbers into the array chatlist. Determine
+     * how much space to allocate for the array with the `$size` function.
+     *
+     * Note that `${savedata.get}` saves all connected conferences;
+     * when toxcore is created from savedata in which conferences were saved, those
+     * conferences will be connected at startup, and will be listed by
+     * `$get`.
+     *
+     * The conference number of a loaded conference may differ from the conference
+     * number it had when it was saved.
      */
     get();
   }
@@ -2638,41 +2658,41 @@ namespace conference {
 
 namespace friend {
 
-  inline namespace send {
+  error for custom_packet {
+    NULL,
+    /**
+     * The friend number did not designate a valid friend.
+     */
+    FRIEND_NOT_FOUND,
+    /**
+     * This client is currently not connected to the friend.
+     */
+    FRIEND_NOT_CONNECTED,
+    /**
+     * The first byte of data was not in the specified range for the packet type.
+     * This range is 192-254 for lossy, and 69, 160-191 for lossless packets.
+     */
+    INVALID,
+    /**
+     * Attempted to send an empty packet.
+     */
+    EMPTY,
+    /**
+     * Packet data length exceeded $MAX_CUSTOM_PACKET_SIZE.
+     */
+    TOO_LONG,
+    /**
+     * Packet queue is full.
+     */
+    SENDQ,
+  }
 
-    error for custom_packet {
-      NULL,
-      /**
-       * The friend number did not designate a valid friend.
-       */
-      FRIEND_NOT_FOUND,
-      /**
-       * This client is currently not connected to the friend.
-       */
-      FRIEND_NOT_CONNECTED,
-      /**
-       * The first byte of data was not in the specified range for the packet type.
-       * This range is 200-254 for lossy, and 160-191 for lossless packets.
-       */
-      INVALID,
-      /**
-       * Attempted to send an empty packet.
-       */
-      EMPTY,
-      /**
-       * Packet data length exceeded $MAX_CUSTOM_PACKET_SIZE.
-       */
-      TOO_LONG,
-      /**
-       * Packet queue is full.
-       */
-      SENDQ,
-    }
+  namespace send {
 
     /**
      * Send a custom lossy packet to a friend.
      *
-     * The first byte of data must be in the range 200-254. Maximum length of a
+     * The first byte of data must be in the range 192-254. Maximum length of a
      * custom packet is $MAX_CUSTOM_PACKET_SIZE.
      *
      * Lossy packets behave like UDP packets, meaning they might never reach the
@@ -2696,7 +2716,7 @@ namespace friend {
     /**
      * Send a custom lossless packet to a friend.
      *
-     * The first byte of data must be in the range 160-191. Maximum length of a
+     * The first byte of data must be in the range 69, 160-191. Maximum length of a
      * custom packet is $MAX_CUSTOM_PACKET_SIZE.
      *
      * Lossless packet behaviour is comparable to TCP (reliability, arrive in order)
@@ -2745,7 +2765,14 @@ namespace friend {
  ******************************************************************************/
 
 
-inline namespace self {
+error for get_port {
+  /**
+   * The instance was not bound to any port.
+   */
+  NOT_BOUND,
+}
+
+namespace self {
 
   uint8_t[PUBLIC_KEY_SIZE] dht_id {
     /**
@@ -2764,13 +2791,6 @@ inline namespace self {
   }
 
 
-  error for get_port {
-    /**
-     * The instance was not bound to any port.
-     */
-    NOT_BOUND,
-  }
-
 
   uint16_t udp_port {
     /**
@@ -2836,5 +2856,7 @@ typedef TOX_CONNECTION Tox_Connection;
 typedef TOX_FILE_CONTROL Tox_File_Control;
 typedef TOX_CONFERENCE_TYPE Tox_Conference_Type;
 
+//!TOKSTYLE+
+
 #endif // C_TOXCORE_TOXCORE_TOX_H
 %}
