@@ -1,7 +1,7 @@
 #ifndef C_TOXCORE_TOXENCRYPTSAVE_DEFINES_H
 #define C_TOXCORE_TOXENCRYPTSAVE_DEFINES_H
 
-#define TOX_ENC_SAVE_MAGIC_NUMBER "toxEsave"
+#define TOX_ENC_SAVE_MAGIC_NUMBER ((const uint8_t *)"toxEsave")
 #define TOX_ENC_SAVE_MAGIC_LENGTH 8
 
 #endif
